Exception: Amp4eLdapTool::LDAPConfigError
- Inherits:
-
StandardError
- Object
- StandardError
- Amp4eLdapTool::LDAPConfigError
- Defined in:
- lib/amp4e_ldap_tool/errors.rb
Instance Method Summary collapse
-
#initialize(msg: "The LDAP Section of the configuration file is not formatted properly") ⇒ LDAPConfigError
constructor
A new instance of LDAPConfigError.
Constructor Details
#initialize(msg: "The LDAP Section of the configuration file is not formatted properly") ⇒ LDAPConfigError
Returns a new instance of LDAPConfigError.
9 10 11 |
# File 'lib/amp4e_ldap_tool/errors.rb', line 9 def initialize(msg: "The LDAP Section of the configuration file is not formatted properly") super end |